==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/docprops/lang/ro.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'docprops', 'ro', {
	bgColor: 'Culoarea fundalului (Background Color)',
	bgFixed: 'Fundal neflotant, fix (Non-scrolling Background)',
	bgImage: 'URL-ul imaginii din fundal (Background Image URL)',
	charset: 'Encoding setului de caractere',
	charsetASCII: 'ASCII', // MISSING
	charsetCE: 'Central European', // MISSING
	charsetCR: 'Chirilic',
	charsetCT: 'Chinezesc tradiţional (Big5)',
	charsetGR: 'Grecesc',
	charsetJP: 'Japonez',
	charsetKR: 'Corean',
	charsetOther: 'Alt encoding al setului de caractere',
	charsetTR: 'Turcesc',
	charsetUN: 'Unicode (UTF-8)', // MISSING
	charsetWE: 'Vest european',
	chooseColor: 'Alege',
	design: 'Design', // MISSING
	docTitle: 'Titlul paginii',
	docType: 'Document Type Heading', // MISSING
	docTypeOther: 'Alt Document Type Heading',
	label: 'Proprietăţile documentului',
	margin: 'Marginile paginii',
	marginBottom: 'Jos',
	marginLeft: 'Stânga',
	marginRight: 'Dreapta',
	marginTop: 'Sus',
	meta: 'Meta Tags', // MISSING
	metaAuthor: 'Autor',
	metaCopyright: 'Drepturi de autor',
	metaDescription: 'Descrierea documentului',
	metaKeywords: 'Cuvinte cheie după care se va indexa documentul (separate prin virgulă)',
	other: '<alt>',
	previewHtml: '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>', // MISSING
	title: 'Proprietăţile documentului',
	txtColor: 'Culoarea textului',
	xhtmlDec: 'Include declaraţii XHTML'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/docprops/lang/ro.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'docprops', 'ro', {
	bgColor: 'Culoarea fundalului (Background Color)',
	bgFixed: 'Fundal neflotant, fix (Non-scrolling Background)',
	bgImage: 'URL-ul imaginii din fundal (Background Image URL)',
	charset: 'Encoding setului de caractere',
	charsetASCII: 'ASCII',
	charsetCE: 'Europa Centrală',
	charsetCR: 'Chirilic',
	charsetCT: 'Chinezesc tradiţional (Big5)',
	charsetGR: 'Grecesc',
	charsetJP: 'Japonez',
	charsetKR: 'Corean',
	charsetOther: 'Alt encoding al setului de caractere',
	charsetTR: 'Turcesc',
	charsetUN: 'Unicode (UTF-8)',
	charsetWE: 'Vest european',
	chooseColor: 'Alege',
	design: 'Proiect',
	docTitle: 'Titlul paginii',
	docType: 'Tip de document de antet',
	docTypeOther: 'Alt Document Type Heading',
	label: 'Proprietăţile documentului',
	margin: 'Marginile paginii',
	marginBottom: 'Jos',
	marginLeft: 'Stânga',
	marginRight: 'Dreapta',
	marginTop: 'Sus',
	meta: 'Tag-uri Meta',
	metaAuthor: 'Autor',
	metaCopyright: 'Drepturi de autor',
	metaDescription: 'Descrierea documentului',
	metaKeywords: 'Cuvinte cheie după care se va indexa documentul (separate prin virgulă)',
	other: 'Altele...',
	previewHtml: '<p>Acesta este un <strong>text exemplu</strong>. Folosiți <a href="javascript:void(0)">CKEditor</a>.</p>',
	title: 'Proprietăţile documentului',
	txtColor: 'Culoarea textului',
	xhtmlDec: 'Include declaraţii XHTML'
} );
